@@ -424,11 +424,11 @@ public:
     /** Recalculate best prefixes and suffixes. */
     void
     recalculate() {
-        MYRRH_ASSERT( boost::size( best_suffixes ) == int( pssm.log_probs.W() + 1 ) );
+        MYRRH_ASSERT( boost::size( best_suffixes ) == size_t( pssm.log_probs.W() + 1 ) );
         best_suffixes[ pssm.log_probs.W() ] = 0.;
         calculate_best_fixes( pssm.log_probs.m.rbegin(), pssm.log_probs.m.rend(), best_suffixes.rbegin() + 1 );
 
-        MYRRH_ASSERT( boost::size( best_prefixes ) == int( pssm.log_probs.W() + 1 ) );
+        MYRRH_ASSERT( boost::size( best_prefixes ) == size_t( pssm.log_probs.W() + 1 ) );
         best_prefixes[ pssm.log_probs.W() ] = 0.;
         calculate_best_fixes( pssm.log_probs.m.begin(), pssm.log_probs.m.end(), best_prefixes.rbegin() + 1 );
 
