@@ -74,6 +74,8 @@ struct dense_base_resolution_psp
 		}
 	}
 
+	virtual ~dense_base_resolution_psp() { }
+
 	/// Return the maximal PSP for all the bases in the given range
 	virtual
 	double
@@ -132,6 +134,8 @@ struct sparse_base_resolution_psp
 		}
 	}
 
+	virtual ~sparse_base_resolution_psp() { }
+
 	/// Return the maximal PSP for all the bases in the given range
 	virtual
 	double
@@ -329,6 +333,8 @@ public:
         update();
     }
 
+    virtual ~dense_psp() { }
+
     /// update after base-resolution priors have changed.
     virtual
     void
@@ -402,6 +408,8 @@ public:
         update();
     }
 
+    virtual ~sparse_psp() { }
+
     /// update after base-resolution priors have changed.
     virtual
     void
